Module prelude

Module prelude 

Prelude containing everything that will likely be needed while using Account

This includes everything in the crate except the trait Incrementable

Structs

Account
A HashMap wrapper for layered settings.
Stg
type abstraction for types implementing Setting
Valid
Account’s validity tracker

Enums

DeepError
Errors involving Deep Functions
StgError
Errors for Stg and StgTrait methods

Traits

Setting
Required trait for conversion to abstract type Stg
StgTrait
Stg container converter trait