pub enum DeepError {
NotFound,
EmptyVec,
}Expand description
Errors involving Deep Functions
Variants
NotFound
Error of providing a name of a child Account that doesn’t exist
EmptyVec
Error of providing a empty Vec to a deep function